
body <- dashboardBody(

  fluidRow(
    
    box(title = "Crime Frequency", solidHeader = TRUE 
        ,collapsible = TRUE, plotOutput("barplot")),
    
    #Adding another box to our fluidRow
    box(title = "Map View", solidHeader = TRUE 
        ,collapsible = TRUE, leafletOutput("mapview"))
    
  )
)

header <- dashboardHeader(title = "Boston Police")

sidebar <- dashboardSidebar(

  radioButtons("year", "Select Year: ",
               c("2015" = "2015",
                 "2016" = "2016",
                 "2017" = "2017",
                 "2018" = "2018",
                 "2019" = "2019")),
  
  #Adding a dropdown menu within the sidebar
  selectInput("offense",
              "Offense Group:",
              c(unique(as.character(df$OFFENSE_CODE_GROUP[1:10]))))

)

ui <- dashboardPage(header, sidebar, body)


server <- function(input, output) {
  
  output$barplot <- renderPlot({
    
    df_fil <- filter(df, YEAR == input$year)
    df_fil_grp <- filter(df_fil,  OFFENSE_CODE_GROUP == input$offense)
    ggplot(data = df_fil_grp, aes(x = df_fil_grp$HOUR)) + geom_bar() + xlab("Hour") + ylab("Number of Crimes") + theme_minimal()
    
  })

  #Defining our 'mapview' plot declared in the UI above
  output$mapview <- renderLeaflet({
    
    df_fil <- filter(df, YEAR == input$year)
    df_fil_grp <- filter(df_fil, OFFENSE_CODE_GROUP == input$offense)
    dm <- data.frame(latitude = df_fil_grp$Lat, longitude = df_fil_grp$Long)

      leaflet(dm) %>% addProviderTiles("Stamen.TonerLite") %>%  
      addMarkers(
        clusterOptions = markerClusterOptions()
      ) %>% setView(-71.1, 42.32, zoom = 12)

  })
  
}


shinyApp(ui = ui, server = server)

