
row <- fluidRow( 
  
  #tabBox layout with multiple tab panels. Each panel has a plot Output
  tabBox(
    title = "Crime Frequency",
    id = "tabset1", height = "250px",
    tabPanel("Per Month", plotOutput("permonth")),
    tabPanel("Per Weekday", plotOutput("perday")),
    tabPanel("Per Hour", plotOutput("perhour"))
  )
  
  ,box(title = "Map View", solidHeader = TRUE 
       ,collapsible = TRUE, leafletOutput("mymap"))
)


#Adding components to body:
body <- dashboardBody(row)


header <- dashboardHeader(title = "Boston Crime Dataset")

sidebar <- dashboardSidebar(
  radioButtons("year", "Select Year: ",
               c("2015" = "2015",
                 "2016" = "2016",
                 "2017" = "2017",
                 "2018" = "2018",
                 "2019" = "2019")),
  
  selectInput("offense",
              "Offense Group:",
              c(unique(as.character(df$OFFENSE_CODE_GROUP[1:10]))))
  
)

#Adding all components to UI:
ui <- dashboardPage(header, sidebar, body)



## Project Boston Crimes: Server
server <- function(input, output) { 
  
  #creating the plotOutput content
  output$permonth <- renderPlot({
    df_fil <- filter(df, YEAR == input$year)
    df_fil_grp <- filter(df_fil,  OFFENSE_CODE_GROUP == input$offense)
    ggplot(data = df_fil_grp,aes(x = df_fil_grp$MONTH)) + geom_bar(fill="steelblue") + xlab("Month") + ylab("Number of Crimes") + theme_minimal()
  })
  
  output$perday <- renderPlot({
    df_fil <- filter(df, YEAR == input$year)
    df_fil_grp <- filter(df_fil,  OFFENSE_CODE_GROUP == input$offense)
    ggplot(data = df_fil_grp,aes(x = df_fil_grp$DAY_OF_WEEK)) + geom_bar(fill="red") + xlab("Day of Week") + ylab("Number of Crimes") + theme_minimal()
  })
  
  output$perhour <- renderPlot({
    df_fil <- filter(df, YEAR == input$year)
    df_fil_grp <- filter(df_fil,  OFFENSE_CODE_GROUP == input$offense)
    ggplot(data = df_fil_grp,aes(x = df_fil_grp$HOUR)) + geom_bar(fill="purple") + xlab("Hour") + ylab("Number of Crimes") + theme_minimal()
  })
  

  output$mymap <- renderLeaflet({
    
    df_fil <- filter(df, YEAR == input$year)
    df_fil_grp <- filter(df_fil, OFFENSE_CODE_GROUP == input$offense)
    dm <- data.frame(latitude = df_fil_grp$Lat, longitude = df_fil_grp$Long)
    
    leaflet(dm) %>% addProviderTiles("Stamen.TonerLite") %>%  
      addMarkers(
        clusterOptions = markerClusterOptions()
      ) %>% setView(-71.1, 42.32, zoom = 12)
    
  })
}


## Project Boston Crimes: Building Our App
shinyApp(ui, server)
